<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="pl_PL">
<context>
    <name>@default</name>
    <message>
        <location filename="../src/main.cpp" line="82"/>
        <source>File does not exist</source>
        <translation type="obsolete">Plik nie istnieje</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="86"/>
        <source>The file %1 could not be found. Please check this and try again.</source>
        <translation type="obsolete">Nie można znaleźć pliku %1. Sprawdź to i spróbuj ponownie.</translation>
    </message>
</context>
<context>
    <name>@default</name>
    <message>
        <location filename="../src/main.cpp" line="82"/>
        <source>File does not exist</source>
        <translation type="unfinished">Plik nie istnieje</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="86"/>
        <source>The file %1 could not be found. Please check this and try again.</source>
        <translation type="unfinished">Nie można znaleźć pliku %1. Sprawdź to i spróbuj ponownie.</translation>
    </message>
</context>
<context>
    <name>QDialog</name>
    <message>
        <location filename="" line="134997500"/>
        <source>Program Files</source>
        <translation type="obsolete">Program Files</translation>
    </message>
</context>
<context>
    <name>pageFinished</name>
    <message>
        <location filename="../dialogs/page_setup_finished.ui" line="43"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;iTALC is now installed!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Instalacja iTALC-a dobiegła końca!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_setup_finished.ui" line="61"/>
        <source>iTALC is now completely installed. If you installed the master application you can start it using the start-menu.</source>
        <translation>iTALC jest teraz zainstalowany. Jeśli zainstalowałeś program zarządzający (master) możesz go uruchomić poprzez menu Start.</translation>
    </message>
    <message>
        <location filename="../dialogs/page_setup_finished.ui" line="71"/>
        <source>Save installation settings</source>
        <translation>Zapisz ustawienia instalacji</translation>
    </message>
</context>
<context>
    <name>pageInstallDir</name>
    <message>
        <location filename="../dialogs/page_install_dir.ui" line="37"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Choose installation directory&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Wybierz katalog instalacji&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_install_dir.ui" line="47"/>
        <source>Please choose the directory in which iTALC is going to be installed. It&apos;s recommended to leave the default-directory, but it&apos;s no problem to change it.</source>
        <translation>Wybierz katalog, w którym zostanie zainstalowany iTALC. Zaleca się pozostawienie domyślnego katalogu, ale jego zmiana nie stwarza problemów w działaniu aplikacji.</translation>
    </message>
</context>
<context>
    <name>pageKeyDirs</name>
    <message>
        <location filename="../dialogs/page_key_dirs.ui" line="37"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Directories for keys&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Katalog dla kluczy&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_key_dirs.ui" line="47"/>
        <source>The newly created or imported key(s) need to be installed somewhere. It&apos;s recommended to leave the suggested directories.</source>
        <translation>Utworzone lub zaimportowane klucz(e) muszą być gdzieś zainstalowane. Zaleca się użycie domyślnych katalogów.</translation>
    </message>
    <message>
        <location filename="../dialogs/page_key_dirs.ui" line="73"/>
        <source>Directory to store public key in</source>
        <translation>Katalog dla kluczy publicznych</translation>
    </message>
    <message>
        <location filename="../dialogs/page_key_dirs.ui" line="147"/>
        <source>Directory to store private key in</source>
        <translation>Katalog dla kluczy prywatnych</translation>
    </message>
    <message>
        <location filename="../dialogs/page_key_dirs.ui" line="212"/>
        <source>You can choose a directory in which to export the public key, e.g. a USB-drive or a network share.</source>
        <translation>Możesz wybrać katalog, do którego zostanie wyeksportowany klucz publiczny, np. pendrive lub dysk sieciowy.</translation>
    </message>
    <message>
        <location filename="../dialogs/page_key_dirs.ui" line="258"/>
        <source>Export private key too</source>
        <translation>Wyeksportuj również klucz prywatny</translation>
    </message>
</context>
<context>
    <name>pageLicenseAgreement</name>
    <message>
        <location filename="../dialogs/page_license_agreement.ui" line="40"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;License agreement&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Umowa licencyjna&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_license_agreement.ui" line="50"/>
        <source>iTALC is published under the terms of the General Public License (GPL). Please read the following license terms and choose whether you agree or disagree the license.</source>
        <translation>iTALC jest rozpowszechniany na warunkach General Public License (GPL). Zapoznaj się z poniższymi warunkami licencji i zdecyduj, czy wyrażasz na nie zgodę czy nie.</translation>
    </message>
    <message>
        <location filename="../dialogs/page_license_agreement.ui" line="81"/>
        <source>I agree</source>
        <translation>Zgadzam się</translation>
    </message>
    <message>
        <location filename="../dialogs/page_license_agreement.ui" line="88"/>
        <source>I disagree</source>
        <translation>Nie zgadzam się</translation>
    </message>
</context>
<context>
    <name>pageSecurityOptions</name>
    <message>
        <location filename="../dialogs/page_security_options.ui" line="53"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Security options&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Opcje bezpieczeństwa&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_security_options.ui" line="63"/>
        <source>iTALC has a sophisticated security-concept for preventing unauthorized access to computers having iTALC client software installed. Therefore you either have to create a new key-pair or import the public key created during iTALC installation on master computer.</source>
        <translation>iTALC używa zaawansowanego modelu bezpieczeństwa aby zapobiec nieautoryzowanym próbom dostępu do komputerów z zainstalowanym klientem iTALC. Z tego względu musisz albo utworzyć nową parę kluczy, albo zaimportować klucz publiczny utworzony w trakcie instalacji iTALC na komputerze zarządcy.</translation>
    </message>
    <message>
        <location filename="../dialogs/page_security_options.ui" line="73"/>
        <source>Create a new key-pair (only do that on master computer)</source>
        <translation>Utwórz nową parę kluczy (rób to tylko na komputerze zarządcy)</translation>
    </message>
    <message>
        <location filename="../dialogs/page_security_options.ui" line="80"/>
        <source>Import public key of master computer</source>
        <translation>Importuj klucz publiczny z komputera zarządcy</translation>
    </message>
    <message>
        <location filename="../dialogs/page_security_options.ui" line="114"/>
        <source>Choose location of exported public key:</source>
        <translation>Wybierz lokalizację wyeksportowanego klucza publicznego:</translation>
    </message>
    <message>
        <location filename="../dialogs/page_security_options.ui" line="152"/>
        <source>Keep all keys (only when updating existing installation!)</source>
        <translation>Zachowaj wszystkie klucze (tylko przy aktualizacji istniejącej instalacji!)</translation>
    </message>
</context>
<context>
    <name>pageSelectComponents</name>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="37"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Select components to install&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Wybierz moduły do zainstalowania&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="55"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Now it&apos;s time to choose which components of iTALC you want to install on this computer. If this is a client-computer you should only install the client-software.&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600; font-style:italic;&quot;&gt;Please note, that the master application depends the client-software in order to function properly.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Wybierz teraz moduły iTALC do zainstalowania. Jeżeli jest to komputer kliencki powinieneś zainstalować tylko oprogramowanie klienta.&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600; font-style:italic;&quot;&gt;Proszę zauważyć, że aplikacja zarządzająca do poprawnego działania wymaga oprogramowania klienckiego.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="70"/>
        <source>Components</source>
        <translation>Moduły</translation>
    </message>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="93"/>
        <source>iTALC Client Appliction (ICA)</source>
        <translation>iTALC program klienta (ICA)</translation>
    </message>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="103"/>
        <source>iTALC Master Application (IMA)</source>
        <translation>iTALC aplikacja zarządzająca (IMA)</translation>
    </message>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="113"/>
        <source>Online-Update Service (LUPUS)</source>
        <translation>Usługa aktualizacji online (LUPUS)</translation>
    </message>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="123"/>
        <source>iTALC documentation</source>
        <translation>Dokumentacja iTALC</translation>
    </message>
</context>
<context>
    <name>pageWelcome</name>
    <message>
        <location filename="../dialogs/page_welcome.ui" line="43"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Welcome to installation of iTALC&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Witaj w programie instalacyjnym iTALC-a&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_welcome.ui" line="61"/>
        <source>This setup-wizard will guide you through the installation of iTALC on this computer. The installation includes the client-software as well as the optional master-application.

Furthermore you&apos;ll be able to setup security-settings.

Click &apos;Next&apos; to continue.</source>
        <translation>Ten kreator poprowadzi Cię przez proces instalacji iTALC na tym komputerze. Instalacja zawiera modul klienta jak również opcjonalny moduł zarządzający.

Ponadto będziesz mógł wybrać ustawienia zabezpieczeń.

Kliknij &apos;Dalej&apos; aby kontynuować.</translation>
    </message>
</context>
<context>
    <name>setupWizard</name>
    <message>
        <location filename="../src/dialogs.cpp" line="155"/>
        <source>Confirm overwrite</source>
        <translation>Potwierdź nadpisanie</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="156"/>
        <source>Do you want to overwrite %1?</source>
        <translation>Czy chcesz zastapić %1?</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="212"/>
        <source>Installing iTALC</source>
        <translation>Instalowanie iTALC</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="214"/>
        <source>Copying files...</source>
        <translation>Kopiowanie plików...</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="279"/>
        <source>Registering ICA as service...</source>
        <translation>Rejestrowanie (ICA) jako usługi...</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="322"/>
        <source>Creating/importing keys...</source>
        <translation>Tworzenie/importowanie kluczy...</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="354"/>
        <source>Creating shortcuts...</source>
        <translation>Tworzenie skrótów...</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="376"/>
        <source>Could not create directory</source>
        <translation>Nie można utworzyć katalogu</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="380"/>
        <source>Could not create directory %1! Make sure you have the neccessary rights and try again!</source>
        <translation>Nie można utworzyć katalogu %1! Upewnij się, czy masz odpowiednie uprawnienia i spróbuj ponownie!</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="393"/>
        <source>Cancel setup</source>
        <translation>Przerwij instalację</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="395"/>
        <source>Are you sure want to quit setup? iTALC is not installed completely yet!</source>
        <translation>Czy chcesz zakończyć instalację? iTALC nie jest jeszcze całkowicie zainstalowany!</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="416"/>
        <source>Next</source>
        <translation>Dalej</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="475"/>
        <source>Finish</source>
        <translation>Zakończ</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="481"/>
        <source>Quit</source>
        <translation>Wyjdź</translation>
    </message>
</context>
<context>
    <name>setupWizardPageInstallDir</name>
    <message>
        <location filename="../src/dialogs.cpp" line="590"/>
        <source>Directory does not exist</source>
        <translation>Katalog nie istnieje</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="592"/>
        <source>The specified directory does not exist. Do you want to create it?</source>
        <translation>Podany katalog nie istnieje. Czy chcesz go utworzyć?</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="614"/>
        <source>Choose installation directory</source>
        <translation>Wybierz katalog instalacji</translation>
    </message>
</context>
<context>
    <name>setupWizardPageKeyDirs</name>
    <message>
        <location filename="../src/dialogs.cpp" line="848"/>
        <source>Choose public key directory</source>
        <translation>Wybierz katalog na klucz publiczny</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="862"/>
        <source>Choose private key directory</source>
        <translation>Wybierz katalog na klucz prywatny</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="876"/>
        <source>Choose public key export directory</source>
        <translation>Wybierz katalog na wyeksportowany klucz publiczny</translation>
    </message>
</context>
<context>
    <name>setupWizardPageSecurityOptions</name>
    <message>
        <location filename="../src/dialogs.cpp" line="750"/>
        <source>Choose directory for key-import</source>
        <translation>Wybierz katalog do importu klucza</translation>
    </message>
</context>
<context>
    <name>wizard</name>
    <message>
        <location filename="../dialogs/wizard.ui" line="21"/>
        <source>iTALC-Setup</source>
        <translation>Instalator iTALC</translation>
    </message>
    <message>
        <location filename="../dialogs/wizard.ui" line="67"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../dialogs/wizard.ui" line="77"/>
        <source>Back</source>
        <translation>Powrót</translation>
    </message>
    <message>
        <location filename="../dialogs/wizard.ui" line="87"/>
        <source>Next</source>
        <translation>Dalej</translation>
    </message>
</context>
</TS>
